@@ -1,9 +1,8 @@
 import datetime
 
-from je_api_testka.requests_wrapper.requests_data_structure import api_tester_method
+from je_api_testka.requests_wrapper.requests_http_method_wrapper import api_tester_method
 from requests.structures import CaseInsensitiveDict
 
-from je_api_testka.utils.exception.api_test_exceptions import APITesterException
 from je_api_testka.utils.exception.api_test_exceptions import APITesterGetDataException
 from je_api_testka.utils.get_data_strcture.get_api_data import get_api_response_data
 
@@ -18,7 +17,9 @@ from je_api_testka.utils.exception.api_test_eceptions_tag import api_test_option
 from je_api_testka.utils.exception.api_test_eceptions_tag import api_test_patch_error_message
 from je_api_testka.utils.exception.api_test_eceptions_tag import api_test_session_error_message
 
-from je_api_testka.record.record import record
+from je_api_testka.utils.test_record.record_test_result_class import test_record
+
+from je_api_testka.utils.assert_result.result_check import check_result
 
 exception_message_dict = {
     "get": api_test_get_error_message,
@@ -48,7 +49,7 @@ def get_response(response, start_time, end_time):
 
 def test_api_method(http_method: str, test_url: str,
                     soap: bool = False, record_request_info: bool = True,
-                    clean_record: bool = False, **kwargs):
+                    clean_record: bool = False, result_check_dict: dict = None, **kwargs):
     start_time = datetime.datetime.now()
     if soap is False:
         response = api_tester_method(http_method, test_url=test_url, **kwargs)
@@ -59,7 +60,11 @@ def test_api_method(http_method: str, test_url: str,
     end_time = datetime.datetime.now()
     response_data = get_response(response, start_time, end_time)
     if record_request_info:
-        record.record_list.append(response_data)
+        test_record.record_list.append(response_data)
     elif clean_record:
-        record.clean_record()
-    return {"response": response, "response_data": response_data}
+        test_record.clean_record()
+    if result_check_dict is None:
+        return {"response": response, "response_data": response_data}
+    else:
+        check_result(response_data, result_check_dict)
+        return {"response": response, "response_data": response_data}
